@@ -1,40 +1,59 @@
 /******************************************************************************/
 /*                                                                            */
-/*  Title       : sattrack.h                                                  */
-/*  Author      : Manfred Bester                                              */
-/*  Date        : 24Feb92                                                     */
-/*  Last change : 06May96                                                     */
+/* Title       : sattrack.h                                                   */
+/* Author      : Manfred Bester                                               */
+/* Date        : 24Feb92                                                      */
+/* Last change : 14Jan97                                                      */
 /*                                                                            */
-/*  Synopsis    : Definitions of constants and parameters for 'sattrack'      */
-/*                and other related programs.                                 */
+/* Synopsis    : Definitions of constants and parameters for 'sattrack'       */
+/*               and other related programs.                                  */
 /*                                                                            */
 /*                                                                            */
-/*  SatTrack is Copyright (c) 1992, 1993, 1994, 1995 by Manfred Bester.       */
-/*  All Rights Reserved.                                                      */
+/* SatTrack V3.1                                                              */
 /*                                                                            */
-/*  Permission to use, copy, and distribute SatTrack and its documentation    */
-/*  in its entirety for educational, research and non-profit purposes,        */
-/*  without fee, and without a written agreement is hereby granted, provided  */
-/*  that the above copyright notice and the following three paragraphs appear */
-/*  in all copies. SatTrack may be modified for personal purposes, but        */
-/*  modified versions may NOT be distributed without prior consent of the     */
-/*  author.                                                                   */
+/* Copyright (c) 1992-1997 Bester Tracking Systems. All Rights Reserved.      */
 /*                                                                            */
-/*  Permission to incorporate this software into commercial products may be   */
-/*  obtained from the author, Dr. Manfred Bester, 1636 M. L. King Jr. Way,    */
-/*  Berkeley, CA 94709, USA. Note that distributing SatTrack 'bundled' in     */
-/*  with ANY product is considered to be a 'commercial purpose'.              */
+/* Permission to use, copy, and distribute SatTrack V3.1 and its              */
+/* documentation in its entirety for educational, research and non-profit     */
+/* purposes, without fee, and without a written agreement is hereby granted,  */
+/* provided that the above copyright notice and the following three           */
+/* paragraphs appear in all copies. SatTrack may be modified for personal     */
+/* purposes, but modified versions may NOT be distributed without prior       */
+/* consent of Bester Tracking Systems.                                        */
 /*                                                                            */
-/*  IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, */
-/*  SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF   */
-/*  THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE AUTHOR HAS BEEN ADVISED  */
-/*  OF THE POSSIBILITY OF SUCH DAMAGE.                                        */
+/* Permission to incorporate this software into commercial products may be    */
+/* obtained Bester Tracking Systems at the address below.                     */
 /*                                                                            */
-/*  THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT      */
-/*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A   */
-/*  PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"      */
-/*  BASIS, AND THE AUTHOR HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT, */
-/*  UPDATES, ENHANCEMENTS, OR MODIFICATIONS.                                  */
+/*                                                                            */
+/*     Bester Tracking Systems                                                */
+/*     P.O. Box 8899                                                          */
+/*     Emeryville, CA 94662, USA                                              */
+/*                                                                            */
+/*     Phone: (510) 654-7824                                                  */
+/*     Email: license@bester.com                                              */
+/*     WWW:   www.bester.com                                                  */
+/*                                                                            */
+/*                                                                            */
+/* Note that distributing SatTrack 'bundled' in with ANY product is           */
+/* considered to be a 'commercial purpose'.                                   */
+/*                                                                            */
+/* IN NO EVENT SHALL BESTER TRACKING SYSTEMS, ITS OWNER OR ITS EMPLOYEES BE   */
+/* LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR          */
+/* CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS      */
+/* DOCUMENTATION, EVEN IF BESTER TRACKING SYSTEMS HAS BEEN ADVISED OF THE     */
+/* POSSIBILITY OF SUCH DAMAGE.                                                */
+/*                                                                            */
+/* BESTER TRACKING SYSTEMS SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING,  */
+/* BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS  */
+/* FOR A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS" */
+/* BASIS, AND BESTER TRACKING SYSTEMS, ITS OWNER OR ITS EMPLOYEES HAVE NO     */
+/* OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR     */
+/* MODIFICATIONS FREE OF CHARGE.                                              */
+/*                                                                            */
+/* Federal and international laws provide severe civil and criminal           */
+/* penalties for the unauthorized reproduction and distribution of            */
+/* copyrighted software. Criminal copyright infringement is investigated      */
+/* by the FBI and may constitute a felony with severe penalties.              */
 /*                                                                            */
 /******************************************************************************/
 
@@ -71,7 +90,7 @@
 #define MODES                 "modes.dat"
 #define TLEX                  "tlex.dat"
 
-#define REGMAIL               "bester@primenet.com"
+#define REGMAIL               "regist@bester.com"
 
 /******************************************************************************/
 /*                                                                            */
@@ -425,8 +444,8 @@
 #define MAXFREQS              10               /* max. number sat frequencies */
 #define MAXMODES              10               /* max. number sat modes       */
 
-#define MAXCITIES             850              /* max. number of cities       */
-#define MAXSATS               600              /* max. number of satellites   */
+#define MAXCITIES             1000             /* max. number of cities       */
+#define MAXSATS               2500             /* max. number of satellites   */
 #define MAXSTATIONS           10               /* max. number of gnd stations */
 #define MAXTDRS               5                /* max. number of TDRS sats    */
 
@@ -567,12 +586,12 @@
 #define TRKSPOT       (unsigned int) 3         /* half the size of the square */
 #define CTYSPOT       (unsigned int) 1         /* half the size of the square */
 
-#define NSEGS         (int) 120                /* number of segments per rev  */
+#define NSEGS         (int) 360                /* number of segments per rev  */
 #define NREVS         (int) 3                  /* number of revs              */
 #define NSEGSGT       (int) (NSEGS*NREVS + 1)  /* (for ground track)          */
 
 #define NSEGSVC       (int) 180                /* visib circle segments       */
-#define LCNUM         96315
+#define LCNUM         97316
 
 #define NMIRPOINTS    420                      /* max data points in Mir icon */
 #define NSTSPOINTS    210                      /* max data points in STS icon */
